@@ -3,7 +3,7 @@
  *		that either displays or sets the characteristics of
  *		one or more of the system's networking interfaces.
  *
- * Version:	ifconfig 1.27 (1997-08-03)
+ * Version:	ifconfig 1.29 (1997-09-23)
  *
  * Author:	Fred N. van Kempen, <waltje@uwalt.nl.mugnet.org>
  *              and others.  Copyright 1993 MicroWalt Corporation
@@ -161,7 +161,7 @@ static const char *if_port_text[][4] = {
 #include "net-locale.h"
 
 char *Release = RELEASE,
-     *Version = "ifconfig 1.27 (1997-08-03)";
+     *Version = "ifconfig 1.29 (1997-09-23)";
 
 
 int opt_a = 0;				/* show all interfaces		*/
@@ -384,7 +384,7 @@ ife_print(struct interface *ptr)
 
 static void if_getstats(char *ifname, struct interface *ife)
 {
-  FILE *f = fopen("/proc/net/dev", "r");
+  FILE *f = fopen(_PATH_PROCNET_DEV, "r");
   char buf[256];
   int have_byte_counters = 0;
   char *bp;
@@ -632,11 +632,14 @@ set_flag(char *ifname, short flag)
   struct ifreq ifr;
 
   strcpy(ifr.ifr_name, ifname);
-  if (ioctl(skfd, SIOCGIFFLAGS, &ifr) < 0) return(-1);
+  if (ioctl(skfd, SIOCGIFFLAGS, &ifr) < 0) {
+    fprintf(stderr, "%s: unknown interface.\n", ifname);
+    return(-1);
+  }
   ifr.ifr_flags |= flag;
   if (ioctl(skfd, SIOCSIFFLAGS, &ifr) < 0) {
-	fprintf(stderr, "SIOCSIFFLAGS: %s\n", strerror(errno));
-	return(-1);
+    perror("SIOCSIFFLAGS");
+    return -1;
   }
   return(0);
 }
@@ -649,11 +652,14 @@ clr_flag(char *ifname, short flag)
   struct ifreq ifr;
 
   strcpy(ifr.ifr_name, ifname);
-  if (ioctl(skfd, SIOCGIFFLAGS, &ifr) < 0) return(-1);
+  if (ioctl(skfd, SIOCGIFFLAGS, &ifr) < 0) {
+    fprintf(stderr, "%s: unknown interface.\n", ifname);
+    return -1;
+  }
   ifr.ifr_flags &= ~flag;
   if (ioctl(skfd, SIOCSIFFLAGS, &ifr) < 0) {
-	fprintf(stderr, "SIOCSIFFLAGS: %s\n", strerror(errno));
-	return(-1);
+    perror("SIOCSIFFLAGS");
+    return -1;
   }
   return(0);
 }
@@ -863,7 +869,7 @@ main(int argc, char **argv)
 	  }
 	  ifr.ifr_map.port = newport;
 	  if (ioctl(skfd, SIOCSIFMAP, &ifr) < 0) {
-	    fprintf(stderr, "SIOCSIFMAP: %s\n", strerror(errno));
+	    perror("SIOCSIFMAP");
 	    goterr = 1;
 	  }
 	}
